.. image:: https://travis-ci.org/Coverfox/cfblog.svg?branch=master
    :target: https://travis-ci.org/Coverfox/cfblog

.. image:: https://www.quantifiedcode.com/api/v1/project/7d02a86019db4fda96fb2fb8fecce8d2/badge.svg
  :target: https://www.quantifiedcode.com/app/project/7d02a86019db4fda96fb2fb8fecce8d2
  :alt: Code issues

What is cfblog?
===============

It is a blog engine with a peculiar CMS feature, that allows very complex
content to be easily created.

Installation
============

.. code:: bash

    $ pip install cfblog


Contributors
============

* Amit Upadhyay (https://github.com/amitu)
* Vinay Karanam (https://github.com/vinayinvicible)

ChangeLog
=========

https://github.com/Coverfox/cfblog/blob/master/ChangeLog.rst


LICENSE
=======

* BSD
